@@ -23,3 +23,8 @@ class InfluxData:
 
     def query(self, query: str):
         return self._client.query_api().query(query, org=self._org)
+
+    def is_node_healthy(self):
+        status = self._client.health().status
+        print(f"HEALTH {self._client.ready()}")
+        return True  # TODO
